#' @title Insert a footer shape into a document pptx object
#'
#' @description Insert a footer shape into the current slide of a \code{pptx} object.
#' 
#' @param doc \code{\link{pptx}} object
#' @param value character value to add into the footer shape of the current slide. 
#' @param ... further arguments, not used. 
#' @return a document object
#' @examples
#' #START_TAG_TEST
#' 
#' # Create a new document 
#' doc = pptx( title = "title" )
#' 
#' # add a slide with layout "Title Slide"
#' doc = addSlide( doc, slide.layout = "Title Slide" )
#' doc = addTitle( doc, "Presentation title" ) #set the main title
#' doc = addSubtitle( doc , "This document is generated with ReporteRs.")#set the sub-title
#' 
#' ## add a page number on the current slide
#' doc = addFooter( doc, "Hi!" )
#' 
#' writeDoc( doc, "addFooter_example.pptx" )
#' #STOP_TAG_TEST
#' @export
#' @seealso \code{\link{pptx}}, \code{\link{addDate.pptx}}
#' , \code{\link{addPageNumber.pptx}} 
#' @method addFooter pptx
#' @S3method addFooter pptx

addFooter.pptx = function(doc, value, ... ) {

	slide = doc$current_slide 
	
	if( missing( value ) ) stop("value is missing")
	
	if( length( value ) != 1 )
		stop("length of value should be 1.")	
	
	out = .jcall( slide, "I", "addFooter" , as.character(value))
	
	if( isSlideError( out ) ){
		stop( getSlideErrorString( out , "footer") )
	}	
	doc
}

